@@ -2,10 +2,11 @@ package Tie::Hash::Attribute;
 use 5.006;
 use strict;
 use warnings FATAL => 'all';
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 our @ISA = 'Tie::Hash';
 
-sub TIEHASH     { bless {@_[1..@_-1]}, $_[0] }
+our $ATTR_SORT = 0;
+
 sub STORE       { $_[0]{$_[1]}=$_[2] }
 sub SCALAR      { _mk_str($_[0]) }
 sub EXISTS      { exists $_[0]{$_[1]} }
@@ -14,6 +15,13 @@ sub NEXTKEY     { each %{$_[0]} }
 sub DELETE      { delete $_[0]{$_[1]} }
 sub CLEAR       { %{$_[0]} = () }
 
+sub TIEHASH {
+    my $class = shift;
+    my %args  = @_;
+    $ATTR_SORT = 1 if defined $args{sorted};
+    return bless {}, $class;
+}
+
 sub FETCH {
     my $self = shift;
     my $arg  = shift;
@@ -26,7 +34,8 @@ sub _mk_str {
     my $hash = shift;
     my $str = '';
     my %seen;
-    for my $key (sort keys %$hash) {
+    my @keys = $ATTR_SORT ? sort keys %$hash : keys %$hash;
+    for my $key (@keys) {
         next if $seen{lc$key}++;
         my $val = defined($hash->{$key}) ? $hash->{$key} : '';
         $val  = _stringify( $val )  if ref $val eq 'HASH';
@@ -175,6 +184,22 @@ Additional rules for keys and values:
 
 =back
 
+=head1 ORDERING
+
+Since the internal storage for this package is a hash, ordering of
+attribute names (for consistancy) can be achieved by specifying a
+true value for the parameter C<sorted> like so:
+
+  tie my %tag, 'Tie::Hash::Attribute', sorted => 1;
+  %hash = ( foo => 1, bar => 2, baz => 3);
+  print scalar %hash;
+    # bar="2" baz="3" foo="1"
+
+The author wishes to somehow utilize Tie::IxHash to allow the client
+to force desired order, but tieing a tied hash is tricky. Most of time
+attribute order is not important, but it can be in a handful of cases.
+If you run into such a case, please alert the author via a bug report.
+
 =head1 SEE ALSO
 
 =over 4
